@@ -14,9 +14,9 @@ use Carp qw(croak carp cluck);
 
 use vars qw($VERSION);
 
-our $VERSION		= '0.22';
+our $VERSION		= '0.23';
 
-our @ATTRIBUTES		= qw(dn cookie);
+our @ATTRIBUTES		= qw(dn cluster cookie);
 
 our %ATTRIBUTES		= ();
 
@@ -149,6 +149,12 @@ always call this method on completion of a script, as an argument to die, or in
 
 Returns the value of the authentication token.
 
+=head3 cluster ()
+
+	print $ucs->cluster;
+
+Returns the value of cluster as given in the constructor.
+
 =head3 dn ()
 
 	print $ucs->dn;
